@@ -54,8 +54,8 @@ void runSanityChecks(T const& t) {
 #endif
 }
 
-template <template <typename, typename, typename, typename, typename>
-          class TMap>
+template <
+    template <typename, typename, typename, typename, typename> class TMap>
 void testCustomSwap() {
   using std::swap;
 
@@ -80,8 +80,7 @@ TEST(F14Map, customSwap) {
 }
 
 template <
-    template <typename, typename, typename, typename, typename>
-    class TMap,
+    template <typename, typename, typename, typename, typename> class TMap,
     typename K,
     typename V>
 void runAllocatedMemorySizeTest() {
@@ -2263,6 +2262,27 @@ TEST(F14Map, containsHashedKey) {
   testContainsHashedKey<F14FastMap>();
 }
 
+template <template <class...> class TMap>
+void testContainsHeterogeneousHashedKey() {
+  TMap<std::string, int> m{};
+  std::string key{"hello"};
+  m.insert({key, 1});
+
+  F14HashedKey<std::string_view> hashedKey{key};
+  EXPECT_TRUE(m.contains(hashedKey));
+
+  std::string otherKey{"folly"};
+  F14HashedKey<std::string_view> hashedKeyNotFound{otherKey};
+  EXPECT_FALSE(m.contains(hashedKeyNotFound));
+}
+
+TEST(F14Map, containsHeterogeneousHashedKey) {
+  testContainsHeterogeneousHashedKey<F14ValueMap>();
+  testContainsHeterogeneousHashedKey<F14VectorMap>();
+  testContainsHeterogeneousHashedKey<F14NodeMap>();
+  testContainsHeterogeneousHashedKey<F14FastMap>();
+}
+
 template <template <class...> class TMap>
 void testInsertOrAssignHashedKey() {
   TMap<std::string, int> m{};
