@@ -240,8 +240,9 @@ class StackAwareViaIfAsyncAwaiter {
   explicit StackAwareViaIfAsyncAwaiter(
       folly::Executor::KeepAlive<> executor, Awaitable&& awaitable)
       : viaCoroutine_(CoroutineType::create(std::move(executor))),
-        awaitable_(folly::coro::co_withAsyncStack(
-            static_cast<Awaitable&&>(awaitable))),
+        awaitable_(
+            folly::coro::co_withAsyncStack(
+                static_cast<Awaitable&&>(awaitable))),
         awaiter_(
             get_awaiter(static_cast<WithAsyncStackAwaitable&&>(awaitable_))) {}
 
@@ -693,8 +694,9 @@ class CommutativeWrapperAwaitable {
       std::enable_if_t<folly::ext::must_use_immediately_v<T2>, int> = 0>
   explicit CommutativeWrapperAwaitable(T2 awaitable) noexcept(noexcept(T{
       FOLLY_DECLVAL(T2)}))
-      : inner_(folly::ext::must_use_immediately_unsafe_mover(
-            std::move(awaitable))()) {}
+      : inner_(
+            folly::ext::must_use_immediately_unsafe_mover(
+                std::move(awaitable))()) {}
 
   template <typename Factory>
   explicit CommutativeWrapperAwaitable(std::in_place_t, Factory&& factory)
@@ -832,8 +834,8 @@ class CommutativeWrapperAwaitable {
 };
 
 template <typename T>
-class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] TryAwaitable
-    : public CommutativeWrapperAwaitable<TryAwaitable, T> {
+class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]]
+TryAwaitable : public CommutativeWrapperAwaitable<TryAwaitable, T> {
  public:
   using CommutativeWrapperAwaitable<TryAwaitable, T>::
       CommutativeWrapperAwaitable;
@@ -845,7 +847,7 @@ class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] TryAwaitable
           int> = 0,
       typename T2 = like_t<Self, T>,
       std::enable_if_t<is_awaitable_v<T2>, int> = 0>
-  friend TryAwaiter<T2> operator co_await(Self && self) {
+  friend TryAwaiter<T2> operator co_await(Self&& self) {
     return TryAwaiter<T2>{static_cast<Self&&>(self).inner_};
   }
 
@@ -875,61 +877,6 @@ template <typename T>
 using semi_await_try_result_t = await_result_t<semi_await_awaitable_t<
     decltype(folly::coro::co_awaitTry(FOLLY_DECLVAL(T)))>>;
 
-namespace detail {
-
-template <typename T, std::enable_if_t<!noexcept_awaitable_v<T>, int> = 0>
-class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] NothrowAwaitable;
-
-// Workaround for bug in LLVM <= 17, where `CommutativeWrapperAwaitable` is sad
-// that `NothrowAwaitable` has 2 template params, even though 1 is defaulted.
-template <typename T>
-using NothrowAwaitableWorkaround = NothrowAwaitable<T>;
-
-// The `!noexcept_awaitable_v` constraint stops `co_nothrow()` from wrapping
-// `co_await_result`, `co_awaitTry`, `AsNoexcept`, etc.
-//
-// Rationale: Instead, we could do:
-//   - (not very useful) Nothing -- modeling the behavior that the exception
-//     was already captured by the inner type.
-//   - (highly unexpected / buggy) Prevent the inner type from capturing the
-//     exception, and force its propagation up-stack.
-// This was banned because real-world users didn't uniformly expect one of the
-// behaviors over the other, and nobody really **needs** this to work.
-template <typename T, std::enable_if_t<!noexcept_awaitable_v<T>, int>>
-class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] NothrowAwaitable
-    : public CommutativeWrapperAwaitable<NothrowAwaitableWorkaround, T> {
- public:
-  using CommutativeWrapperAwaitable<NothrowAwaitableWorkaround, T>::
-      CommutativeWrapperAwaitable;
-
-  T&& unwrap() { return std::move(this->inner_); }
-};
-
-} // namespace detail
-
-template <
-    typename Awaitable,
-    std::enable_if_t<
-        !noexcept_awaitable_v<Awaitable> && // Comment on `NothrowAwaitable`
-            !folly::ext::must_use_immediately_v<Awaitable>,
-        int> = 0>
-detail::NothrowAwaitable<remove_cvref_t<Awaitable>> co_nothrow(
-    [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE_ARGUMENT]] Awaitable&& awaitable) {
-  return detail::NothrowAwaitable<remove_cvref_t<Awaitable>>{
-      static_cast<Awaitable&&>(awaitable)};
-}
-template <
-    typename Awaitable,
-    std::enable_if_t<
-        !noexcept_awaitable_v<Awaitable> && // Comment on `NothrowAwaitable`
-            folly::ext::must_use_immediately_v<Awaitable>,
-        int> = 0>
-detail::NothrowAwaitable<remove_cvref_t<Awaitable>> co_nothrow(
-    [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE_ARGUMENT]] Awaitable awaitable) {
-  return detail::NothrowAwaitable<remove_cvref_t<Awaitable>>{
-      folly::ext::must_use_immediately_unsafe_mover(std::move(awaitable))()};
-}
-
 } // namespace folly::coro
 
 #endif // FOLLY_HAS_COROUTINES
