@@ -42,7 +42,7 @@ using tiny_now_task_with_executor_base =
 } // namespace detail
 
 template <typename T>
-class FOLLY_NODISCARD tiny_now_task_with_executor final
+class [[nodiscard]] tiny_now_task_with_executor final
     : public detail::tiny_now_task_with_executor_base<T> {
  protected:
   using detail::tiny_now_task_with_executor_base<
@@ -94,7 +94,7 @@ using TinyMovableTaskWithExecutorBase = TaskWithExecutorWrapperCrtp<
 } // namespace detail
 
 template <typename T>
-class FOLLY_NODISCARD TinyMovableTaskWithExecutor final
+class [[nodiscard]] TinyMovableTaskWithExecutor final
     : public detail::TinyMovableTaskWithExecutorBase<T> {
  protected:
   using detail::TinyMovableTaskWithExecutorBase<
@@ -129,10 +129,8 @@ static_assert(is_semi_awaitable_v<TinyMovableTask<int>>);
 ///////////////////
 
 template <
-    template <typename>
-    class TaskT,
-    template <typename>
-    class TaskWithExecutorT>
+    template <typename> class TaskT,
+    template <typename> class TaskWithExecutorT>
 struct TaskWrapperTest : testing::Test {
   static TaskT<int> intFunc(int x) { co_return x; }
   static TaskT<int> intPtrFunc(auto x) { co_return *x; }
