@@ -66,9 +66,11 @@ class MemoryIdlerTimeout : public AsyncTimeout, public EventBase::LoopCallback {
 
         idleTimeout = MemoryIdler::getVariationTimeout(idleTimeout);
 
-        scheduleTimeout(static_cast<uint32_t>(
-            std::chrono::duration_cast<std::chrono::milliseconds>(idleTimeout)
-                .count()));
+        scheduleTimeout(
+            static_cast<uint32_t>(
+                std::chrono::duration_cast<std::chrono::milliseconds>(
+                    idleTimeout)
+                    .count()));
       } else {
         num_++;
       }
@@ -286,6 +288,8 @@ void IOThreadPoolExecutor::stopThreads(size_t n) {
     }
   }
   for (const auto& thread : stoppedThreads) {
+    stoppedThreadProcessedTasks_ += thread->processedTasks;
+    thread->processedTasks = 0;
     stoppedThreads_.add(thread);
     threadList_.remove(thread);
   }
