@@ -51,9 +51,10 @@ class AsyncDetachFdCallback {
 } // namespace folly
 
 #if FOLLY_HAS_LIBURING
-class IoUringBackend;
 
 namespace folly {
+class IoUringBackend;
+class IoUringProvidedBufferRing;
 
 class AsyncIoUringSocket : public AsyncSocketTransport {
  public:
@@ -61,12 +62,14 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
   struct Options {
     Options()
         : allocateNoBufferPoolBuffer(defaultAllocateNoBufferPoolBuffer),
-          multishotRecv(true) {}
+          multishotRecv(true),
+          useBundles(false) {}
 
     static std::unique_ptr<IOBuf> defaultAllocateNoBufferPoolBuffer();
     folly::Function<std::unique_ptr<IOBuf>()> allocateNoBufferPoolBuffer;
     folly::Optional<AsyncWriter::ZeroCopyEnableFunc> zeroCopyEnable;
     bool multishotRecv;
+    bool useBundles;
   };
 
   using UniquePtr = std::unique_ptr<AsyncIoUringSocket, Destructor>;
@@ -108,6 +111,12 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
     return connectEndTime_ - connectStartTime_;
   }
 
+  /*
+   * This flag controls whether or not IP_BIND_ADDRESS_NO_PORT is enabled for
+   * AsyncSocket sockets. This is enabled by default.
+   */
+  void setBindAddressNoPort(bool flag) { bindAddressNoPort_ = flag; }
+
   // AsyncSocketBase
   EventBase* getEventBase() const override { return evb_; }
 
@@ -226,7 +235,7 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
 
   void asyncDetachFd(AsyncDetachFdCallback* callback);
   bool readSqeInFlight() const { return readSqe_->inFlight(); }
-  bool getTFOSucceded() const override;
+  bool getTFOSucceeded() const override;
   void enableTFO() override {
     // No-op if folly does not allow tfo
 #if FOLLY_ALLOW_TFO
@@ -248,14 +257,14 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
   void unregisterFd();
   void readProcessSubmit(
       struct io_uring_sqe* sqe,
-      IoUringBufferProviderBase* bufferProvider,
+      IoUringProvidedBufferRing* bufferProvider,
       size_t* maxSize,
-      IoUringBufferProviderBase* usedBufferProvider) noexcept;
+      IoUringProvidedBufferRing* usedBufferProvider) noexcept;
   void readCallback(
       int res,
       uint32_t flags,
       size_t maxSize,
-      IoUringBufferProviderBase* bufferProvider) noexcept;
+      IoUringProvidedBufferRing* bufferProvider) noexcept;
   void allowReads();
   void previousReadDone();
   void processWriteQueue() noexcept;
@@ -336,7 +345,7 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
 
     bool isEOF(const io_uring_cqe* cqe) noexcept;
 
-    IoUringBufferProviderBase* lastUsedBufferProvider_;
+    IoUringProvidedBufferRing* lastUsedBufferProvider_;
     ReadCallback* readCallback_ = nullptr;
     AsyncIoUringSocket* parent_;
     size_t maxSize_;
@@ -350,6 +359,7 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
         false; // todo: this can be per process instead of per socket
     bool supportsZeroCopyRx_ = false;
     bool useZeroCopyRx_ = false;
+    bool useBundles_ = false;
 
     folly::Optional<folly::SemiFuture<std::unique_ptr<IOBuf>>>
         oldEventBaseRead_;
@@ -500,6 +510,7 @@ class AsyncIoUringSocket : public AsyncSocketTransport {
   std::chrono::milliseconds connectTimeout_{0};
   std::chrono::steady_clock::time_point connectStartTime_;
   std::chrono::steady_clock::time_point connectEndTime_;
+  bool bindAddressNoPort_{true};
 
   // stopTLS helpers:
   std::string securityProtocol_;
