@@ -1464,17 +1464,17 @@ TEST(Function, TrivialSmallBig) {
 }
 
 TEST(Function, ConstInitEmpty) {
-  static FOLLY_CONSTINIT Function<int()> func;
+  static constinit Function<int()> func;
   EXPECT_THROW(func(), std::bad_function_call);
 }
 
 TEST(Function, ConstInitNullptr) {
-  static FOLLY_CONSTINIT Function<int()> func{nullptr};
+  static constinit Function<int()> func{nullptr};
   EXPECT_THROW(func(), std::bad_function_call);
 }
 
 TEST(Function, ConstInitStaticLambda) {
-  static FOLLY_CONSTINIT Function<int()> func{[] { return 3; }};
+  static constinit Function<int()> func{[] { return 3; }};
   EXPECT_EQ(3, func());
 }
 
@@ -1490,19 +1490,18 @@ union consteval_immortal {
 } // namespace
 
 TEST(Function, ConstEvalEmpty) {
-  static FOLLY_CONSTINIT consteval_immortal<Function<int()>> func{
-      std::in_place};
+  static constinit consteval_immortal<Function<int()>> func{std::in_place};
   EXPECT_THROW(func.value(), std::bad_function_call);
 }
 
 TEST(Function, ConstEvalNullptr) {
-  static FOLLY_CONSTINIT consteval_immortal<Function<int()>> func{
+  static constinit consteval_immortal<Function<int()>> func{
       std::in_place, nullptr};
   EXPECT_THROW(func.value(), std::bad_function_call);
 }
 
 TEST(Function, ConstEvalStaticLambda) {
-  static FOLLY_CONSTINIT consteval_immortal<Function<int()>> func{
+  static constinit consteval_immortal<Function<int()>> func{
       std::in_place, [] { return 3; }};
   EXPECT_EQ(3, func.value());
 }
