@@ -185,6 +185,10 @@ TEST(SharedMutex, basicHolders) {
   runBasicHoldersTest<SharedMutexTracked>();
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// Thse tests fail in an assertion in the TSAN library because there are too
+// many mutexes
+
 template <typename Lock>
 void runManyReadLocksTestWithTokens() {
   Lock lock;
@@ -204,9 +208,6 @@ void runManyReadLocksTestWithTokens() {
 }
 
 TEST(SharedMutex, manyReadLocksWithTokens) {
-  // This test fails in an assertion in the TSAN library because there are too
-  // many mutexes
-  SKIP_IF(folly::kIsSanitizeThread);
   runManyReadLocksTestWithTokens<SharedMutexReadPriority>();
   runManyReadLocksTestWithTokens<SharedMutexWritePriority>();
   runManyReadLocksTestWithTokens<SharedMutexSuppressTSAN>();
@@ -232,13 +233,14 @@ void runManyReadLocksTestWithoutTokens() {
 TEST(SharedMutex, manyReadLocksWithoutTokens) {
   // This test fails in an assertion in the TSAN library because there are too
   // many mutexes
-  SKIP_IF(folly::kIsSanitizeThread);
   runManyReadLocksTestWithoutTokens<SharedMutexReadPriority>();
   runManyReadLocksTestWithoutTokens<SharedMutexWritePriority>();
   runManyReadLocksTestWithoutTokens<SharedMutexSuppressTSAN>();
   runManyReadLocksTestWithoutTokens<SharedMutexTracked>();
 }
 
+#endif
+
 template <typename Lock>
 void runTimeoutInPastTest() {
   Lock lock;
@@ -1164,29 +1166,35 @@ TEST(SharedMutex, deterministicAllOpsReadPrio) {
   }
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// This test fails in TSAN because of noisy lock ordering inversions.
+
 TEST(SharedMutex, deterministicAllOpsWritePrio) {
-  // This test fails in TSAN because of noisy lock ordering inversions.
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < 5; ++pass) {
     DSched sched(DSched::uniform(pass));
     runAllAndValidate<DSharedMutexWritePriority, DeterministicAtomic>(1000, 8);
   }
 }
 
+#endif
+
 TEST(SharedMutex, allOpsReadPrio) {
   for (int pass = 0; pass < 5; ++pass) {
     runAllAndValidate<SharedMutexReadPriority, atomic>(100000, 32);
   }
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// This test fails in TSAN because of noisy lock ordering inversions.
+
 TEST(SharedMutex, allOpsWritePrio) {
-  // This test fails in TSAN because of noisy lock ordering inversions.
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < 5; ++pass) {
     runAllAndValidate<SharedMutexWritePriority, atomic>(100000, 32);
   }
 }
 
+#endif
+
 FOLLY_ASSUME_FBVECTOR_COMPATIBLE(std::optional<std::optional<SharedMutexToken>>)
 
 // Setup is a set of threads that either grab a shared lock, or exclusive
@@ -1300,10 +1308,11 @@ static void runRemoteUnlock(
   }
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// This test fails in an assertion in the TSAN library because there are too
+// many mutexes
+
 TEST(SharedMutex, deterministicRemoteWritePrio) {
-  // This test fails in an assertion in the TSAN library because there are too
-  // many mutexes
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < 1; ++pass) {
     DSched sched(DSched::uniform(pass));
     runRemoteUnlock<DSharedMutexWritePriority, DeterministicAtomic>(
@@ -1311,6 +1320,8 @@ TEST(SharedMutex, deterministicRemoteWritePrio) {
   }
 }
 
+#endif
+
 TEST(SharedMutex, deterministicRemoteReadPrio) {
   for (int pass = 0; pass < 1; ++pass) {
     DSched sched(DSched::uniform(pass));
@@ -1319,24 +1330,24 @@ TEST(SharedMutex, deterministicRemoteReadPrio) {
   }
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// Thse tests fail in an assertion in the TSAN library because there are too
+// many mutexes
+
 TEST(SharedMutex, remoteWritePrio) {
-  // This test fails in an assertion in the TSAN library because there are too
-  // many mutexes
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < 10; ++pass) {
     runRemoteUnlock<SharedMutexWritePriority, atomic>(100000, 0.1, 0.1, 5, 5);
   }
 }
 
 TEST(SharedMutex, remoteReadPrio) {
-  // This test fails in an assertion in the TSAN library because there are too
-  // many mutexes
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < (folly::kIsSanitizeAddress ? 1 : 100); ++pass) {
     runRemoteUnlock<SharedMutexReadPriority, atomic>(100000, 0.1, 0.1, 5, 5);
   }
 }
 
+#endif
+
 static void burn(size_t n) {
   for (size_t i = 0; i < n; ++i) {
     folly::doNotOptimizeAway(i);
@@ -1440,16 +1451,19 @@ static void timed_rd_pri_ping_pong(size_t n, size_t scale, size_t burnCount) {
       n / scale, burnCount);
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// This test fails in TSAN because some mutexes are lock_shared() in one
+// thread and unlock_shared() in a different thread.
+
 TEST(SharedMutex, deterministicPingPongWritePrio) {
-  // This test fails in TSAN because some mutexes are lock_shared() in one
-  // thread and unlock_shared() in a different thread.
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < 1; ++pass) {
     DSched sched(DSched::uniform(pass));
     runPingPong<DSharedMutexWritePriority, DeterministicAtomic>(500, 0);
   }
 }
 
+#endif
+
 TEST(SharedMutex, deterministicPingPongReadPrio) {
   for (int pass = 0; pass < 1; ++pass) {
     DSched sched(DSched::uniform(pass));
@@ -1457,15 +1471,18 @@ TEST(SharedMutex, deterministicPingPongReadPrio) {
   }
 }
 
+#if !FOLLY_SANITIZE_THREAD
+// This test fails in TSAN because some mutexes are lock_shared() in one
+// thread and unlock_shared() in a different thread.
+
 TEST(SharedMutex, pingPongWritePrio) {
-  // This test fails in TSAN because some mutexes are lock_shared() in one
-  // thread and unlock_shared() in a different thread.
-  SKIP_IF(folly::kIsSanitizeThread);
   for (int pass = 0; pass < 1; ++pass) {
     runPingPong<SharedMutexWritePriority, atomic>(50000, 0);
   }
 }
 
+#endif
+
 TEST(SharedMutex, pingPongReadPrio) {
   for (int pass = 0; pass < 1; ++pass) {
     runPingPong<SharedMutexReadPriority, atomic>(50000, 0);
