@@ -65,6 +65,12 @@ struct B {};
 
 } // namespace
 
+TEST(Traits, index_iterals) {
+  using namespace folly::literals;
+  constexpr std::integral_constant val = 17_uzic;
+  EXPECT_EQ(17, val);
+}
+
 namespace folly {
 template <>
 struct IsRelocatable<T1> : std::true_type {};
@@ -113,7 +119,7 @@ TEST(Traits, zeroInit) {
     int i_ = 42;
   };
   struct S3 {
-    int S1::*mp_;
+    int S1::* mp_;
   };
 
   EXPECT_TRUE(IsZeroInitializable<int>::value);
@@ -220,6 +226,13 @@ TEST(Traits, relational) {
   EXPECT_TRUE((folly::greater_than<int64_t, -1, uint64_t>(0)));
 }
 
+TEST(Traits, is_non_bool_integral) {
+  EXPECT_TRUE((folly::is_non_bool_integral_v<int>));
+  EXPECT_TRUE((folly::is_non_bool_integral_v<int const volatile>));
+  EXPECT_FALSE((folly::is_non_bool_integral_v<bool>));
+  EXPECT_FALSE((folly::is_non_bool_integral_v<bool const volatile>));
+}
+
 #if FOLLY_HAVE_INT128_T
 
 TEST(Traits, int128) {
